@@ -12,7 +12,7 @@ use JSON;
 use Fcntl qw(:DEFAULT :flock);
 use IO::Handle;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 sub prepare_app {
     my $self = shift;
@@ -70,17 +70,19 @@ sub call {
     }
 
     my $res = $self->app->($env);
-    if ( ref $res && ref $res eq 'ARRAY' ) {
-        if ( $self->counter_file ) {
-            my $length = Plack::Util::content_length($res->[2]);
-            $self->counter(1,$length);
-        }
-        undef $guard;
-        return $res;
-    }
     Plack::Util::response_cb($res, sub {
         my $res = shift;
-        my $length;
+
+        if ( defined $res->[2] ) {
+            if ( $self->counter_file ) {
+                my $length = Plack::Util::content_length($res->[2]);
+                $self->counter(1,$length);
+            }
+            undef $guard;
+            return ;
+        }
+
+        my $length = 0;
         return sub {
             my $chunk = shift;
             if ( ! defined $chunk ) {
